@@ -1,21 +1,16 @@
-package JSON::T;
-
 use 5.010;
 use strict;
 use warnings;
 use utf8;
 
-use Class::Load qw[];
-use JSON qw[];
-use Scalar::Util qw[];
+package JSON::T;
 
-use Object::AUTHORITY;
 use overload '""' => \&_to_string;
 
 BEGIN
 {
 	$JSON::T::AUTHORITY = 'cpan:TOBYINK';
-	$JSON::T::VERSION   = '0.103';
+	$JSON::T::VERSION   = '0.104';
 }
 
 our ($JSLIB, @Implementations);
@@ -31,7 +26,10 @@ sub _load_lib
 
 BEGIN
 {
-	push @Implementations, qw/JSON::T::JE JSON::T::SpiderMonkey/;
+	push @Implementations, qw/
+		JSON::T::SpiderMonkey
+		JSON::T::JE
+	/;
 }
 
 {
@@ -46,101 +44,126 @@ BEGIN
 
 sub new
 {
-	my ($class, $transformation_code, $transformation_name) = @_;
+	my $class = shift;
+	my ($transformation_code, $transformation_name) = @_;
 	$transformation_name ||= '_main';
-
-	my $impl_class;
+	
 	if ($class eq __PACKAGE__)
 	{
-		IMPL: for my $i (@Implementations)
+		require Module::Runtime;
+		IMPL: for my $subclass (@Implementations)
 		{
-			if (Class::Load::is_class_loaded($i)
-			or  Class::Load::try_load_class($i))
-			{
-				$impl_class = $i;
-				last IMPL;
-			}
-		}
-		
-		# let Class::Load break the bad news
-		unless (defined $impl_class)
-		{
-			$impl_class = $Implementations[0];
-			Class::Load::load_class($impl_class);
+			next IMPL unless eval { Module::Runtime::use_module($subclass) };
+			$class = $subclass;
+			last IMPL;
 		}
 	}
-	else
+	
+	if ($class eq __PACKAGE__)
 	{
-		$impl_class = $class;
+		require Carp;
+		Carp::croak("cannot load any known Javascript engine");
 	}
 	
 	my $self = bless {
-		code           => $transformation_code ,
-		name           => $transformation_name ,
-		messages       => [],
-		}, $impl_class;
+		code      => $transformation_code ,
+		name      => $transformation_name ,
+		messages  => [],
+	}, $class;
 	
 	$self->init;
 	$self->engine_eval($transformation_code);
-	return $self;
+	
+	$self;
 }
 
 sub init
 {
-	my ($self) = @_;
+	my $self = shift;
+	
 	_load_lib;
 	$self->engine_eval($JSLIB);
-	return $self;
+	
+	$self;
 }
 
-sub engine_eval { die "must be implemented by subclass" }
-sub parameters { warn "not implemented by subclass" } # non-fatal
+sub engine_eval { require Carp; Carp::croak("must be implemented by subclass") }
+sub parameters  { require Carp; Carp::carp("not implemented by subclass") }
 
 sub _accept_return_value
 {
-	my ($self, $value) = @_;
+	my $self = shift;
+	my ($value) = @_;
+	
 	$self->{return_value} = $value;
 }
 
 sub _last_return_value
 {
-	my ($self) = @_;
+	my $self = shift;
+	
 	$self->{return_value};
 }
 
 sub _to_string
 {
-	my ($self) = @_;
+	my $self = shift;
+	
 	return 'JsonT:#'.$self->{'name'};
 }
 
+sub _json_backend
+{
+	my $self = shift;
+	
+	$self->{'json_backend'} ||= eval {
+		require Cpanel::JSON::MaybeXS;
+		'Cpanel::JSON::MaybeXS';
+	};
+	$self->{'json_backend'} ||= do {
+		require JSON::PP;
+		'JSON::PP';
+	};
+	
+	$self->{'json_backend'};
+}
+
 sub transform
 {
-	my ($self, $input) = @_;
+	my $self = shift;
+	my ($input) = @_;
 	
-	if (Scalar::Util::blessed($input) and $input->isa('JSON::JOM::Node'))
+	if (ref $input)
 	{
-		$input = JSON::to_json($input, {convert_blessed=>1});
-	}
-	elsif (ref $input)
-	{
-		$input = JSON::to_json($input);
+		require Scalar::Util;
+		if (Scalar::Util::blessed($input) and $input->isa('JSON::JOM::Node'))
+		{
+			$input = $self->_json_backend->new->convert_blessed(1)->encode($input);
+		}
+		else
+		{
+			$input = $self->_json_backend->new->encode($input);
+		}
 	}
 	
 	my $name = $self->{'name'};
 	my $rv1  = $self->engine_eval("return_to_perl(JSON.transform($input, $name));");
 
-	return ($self->_last_return_value//'').''; # stringify
+	($self->_last_return_value // '') . ''; # stringify
 }
 
 sub transform_structure
 {
-	my ($self, $input, $debug) = @_;
+	my $self = shift;
+	my ($input, $debug) = @_;
+	
 	my $output = $self->transform($input);
 	eval 'use Test::More; Test::More::diag("\n${output}\n");'
 		if $debug;
-	return JSON::from_json($output);
+	
+	$self->_json_backend->new->decode($output);
 }
+
 *transform_document = \&transform_structure;
 
 # none of this is useful, but provided for XML::Saxon::XSLT2 compat.
@@ -148,11 +171,15 @@ sub messages
 {
 	return;
 }
+
 sub media_type
 {
-	my ($self, $default) = @_;
-	return $default;
+	my $self = shift;
+	my ($default) = @_;
+	
+	$default;
 }
+
 *version        = \&media_type;
 *doctype_system = \&media_type;
 *doctype_public = \&media_type;
@@ -160,6 +187,15 @@ sub media_type
 
 1;
 
+#
+# Don't include __END__ here because we
+# have a __DATA__ section below the pod!
+#
+
+=pod
+
+=encoding utf-8
+
 =head1 NAME
 
 JSON::T - transform JSON using JsonT
@@ -361,7 +397,7 @@ JsonT (version 0.9) to do the heavy lifting.
 
 Copyright 2006 Stefan Goessner.
 
-Copyright 2008-2011, 2013 Toby Inkster.
+Copyright 2008-2011, 2013-2014 Toby Inkster.
 
 Licensed under the Lesser GPL:
 L<http://creativecommons.org/licenses/LGPL/2.1/>.
